==> vtigercrm-5.3.0p0.tgz: modules/Webmails/language/es_mx.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Webmails
*  Language     : Español
*  Version      : 504
*  Created Date : 2007-03-30 Last change : 2007-10-10
*  Author       : Rafael Soler
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = array (
'LBL_MODULE_NAME'=>'Email',
'LBL_MODULE_TITLE'=>'Email: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Email',
'LBL_LIST_FORM_TITLE'=>'Listado de Email',
'LBL_NEW_FORM_TITLE'=>'Seguimiento de Correo',

'LBL_LIST_SUBJECT'=>'Asunto',
'LBL_LIST_CONTACT'=>'Persona',
'LBL_LIST_RELATED_TO'=>'Relacionado con',
'LBL_LIST_DATE'=>'Fecha de Envío',
'LBL_LIST_TIME'=>'Hora de Envío',
'LBL_MOVE_TO'=>'Mover A',
'LBL_DELETE'=>'Borrar',

'ERR_DELETE_RECORD'=>'Debe especificar un registro para eliminar la cuenta.',
'LBL_DATE_SENT'=>'Fecha de Envío:',
'LBL_SUBJECT'=>'Asunto:',
'LBL_DATE_AND_TIME'=>'Fecha y Hora de Envío:',
'LBL_DATE'=>'Fecha de Envío:',
'LBL_TIME'=>'Hora de Envío:',
'LBL_BODY'=>'Cuerpo:',
'LBL_CONTACT_NAME'=>' Nombre: ',
'LBL_EMAIL'=>'Email:',
'LBL_COLON'=>':',
'LBL_TO'=>'Para :',
'LBL_CHK_MAIL'=>'Comprobar Correo',
'LBL_COMPOSE'=>'Redactar',
'LBL_SETTINGS'=>'Configuración',
'LBL_EMAIL_FOLDERS'=>'Carpetas de Email',
'LBL_INBOX'=>'Bandeja de Entrada',
'LBL_SENT_MAILS'=>'Emails Enviados',
'LBL_TRASH'=>'Papelera',
'LBL_JUNK_MAILS'=>'Eliminados',
'LBL_TO_LEADS'=>'A Prospectos',
'LBL_TO_CONTACTS'=>'A Contactos',
'LBL_TO_ACCOUNTS'=>'A Cuentas',
'LBL_MY_MAILS'=>'Mis Correos',
'LBL_QUAL_CONTACT'=>'Emails Clasificados por Contactos',
'LBL_MAILS'=>'Correos',
'LBL_QUALIFY_BUTTON'=>'Clasificar',
'LBL_REPLY_BUTTON'=>'Responder',
'LBL_FORWARD_BUTTON'=>'Reenviar',
'LBL_DOWNLOAD_ATTCH_BUTTON'=>'Descargar Adjuntos',
'LBL_FROM'=>'De: ',
'LBL_CC'=>'CC: ',
'LBL_REPLY_TO_SENDER'=>'Responder',
'LBL_REPLY_ALL'=>'Responder a Todos',
'LBL_SHOW_HIDDEN'=>'Mostrar Borrados',
'LBL_EXPUNGE_MAILBOX'=>'Borrar Mensajes',

'NTC_REMOVE_INVITEE'=>'¿Está seguro de eliminar esta dirección de Email?',
'LBL_INVITEE'=>'Receptores',

// Added Fields
// Contacts-SubPanelViewContactsAndUsers.php
'LBL_BULK_MAILS'=>'Email en blanco',
'LBL_ATTACHMENT'=>'Adjunto',
'LBL_UPLOAD'=>'Subir',
'LBL_FILE_NAME'=>'Nombre de Archivo',
'LBL_SEND'=>'Enviado',

'LBL_EMAIL_TEMPLATES'=>'Plantillas de Email',
'LBL_TEMPLATE_NAME'=>'Nombre de Plantilla',
'LBL_DESCRIPTION'=>'Descripción',
'LBL_EMAIL_TEMPLATES_LIST'=>'Lista de Plantillas de email',
'LBL_EMAIL_INFORMATION'=>'Información de Email',




//for v4 release added
'LBL_NEW_LEAD'=>'Nuevo Prospecto',
'LBL_LEAD_TITLE'=>'Prospecto',

'LBL_NEW_PRODUCT'=>'Nuevo Producto',
'LBL_PRODUCT_TITLE'=>'Productos',
'LBL_NEW_CONTACT'=>'Nuevo Contacto',
'LBL_CONTACT_TITLE'=>'Contactos',
'LBL_NEW_ACCOUNT'=>'Nueva Cuenta',
'LBL_ACCOUNT_TITLE'=>'Cuentas',

// Added vtiger_fields after vtiger4 - Beta
'LBL_USER_TITLE'=>'Usuarios',
'LBL_NEW_USER'=>'Nuevo Usuario',

// Added for 4 GA
'LBL_TOOL_FORM_TITLE'=>'Herramienta de Email',
//Added for 4GA
'Date & Time Sent'=>'Fecha y Hora de Envío',
'Sales Enity Module'=>'Módulo de Ventas',
'Activtiy Type'=>'Tipo de Actividad',
'Related To'=>'Relacionado con',
'Assigned To'=>'Asignado a',
'Subject'=>'Asunto',
'Attachment'=>'Adjunto',
'Description'=>'Descripción',
'Time Start'=>'Fecha de Inicio',
'Created Time'=>'Creada',
'Modified Time'=>'Modificada',

'MESSAGE_CHECK_MAIL_SERVER_NAME'=>'Por favor compruebe el nombre del servidor de mail...',
'MESSAGE_CHECK_MAIL_ID'=>'Por favor compruebe el Email del usuario \"Asignado a\"...',
'MESSAGE_MAIL_HAS_SENT_TO_USERS'=>'El correo se ha enviado a los siguientes usuarios:',
'MESSAGE_MAIL_HAS_SENT_TO_CONTACTS'=>'El correo se ha enviado a los siguientes contactos:',
'MESSAGE_MAIL_ID_IS_INCORRECT'=>'El Email es incorrecto. Compruebe el Email ...',
'MESSAGE_ADD_USER_OR_CONTACT'=>'Añada un Usuario o Contacto...',
'MESSAGE_MAIL_SENT_SUCCESSFULLY'=>' ¡El Email se ha enviado correctamente!',

// Added for web mail post 4.0.1 release
'LBL_FETCH_WEBMAIL'=>'Actualizar Correo',
//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'Todos',
'MESSAGE_CONTACT_NOT_WANT_MAIL'=>'Este contacto no quiere recibir correos.',
'LBL_WEBMAILS_TITLE'=>'Email',
'LBL_EMAILS_TITLE'=>'Email',
'LBL_MAIL_CONNECT_ERROR_INFO'=>'¡Error conectando con el servidor de email!<br> Compruebe en Configuración -> Lista de Servidores de Correo -> Lista de cuentas de correo',
// Added for 5.0.3 release
'LBL_MAIL_CONNECT_ERROR'=>'No se ha podido conectar al Servidor de Correo. Compruebe la configuración del Servidor ',
'IN_REPLY_TO_THE_MESSAGE' => 'En respuesta al mensaje enviado por',
'LBL_CLICK_HERE' => 'Pinche Aquí ',
'LBL_GOTO_EMAILS_MODULE' => ' para ir al módulo de Email',
'LBL_NO_EMAILS'=>'Carpeta vacía',
'LBL_MOVE_TO'=>'Mover a...',
'LBL_DEL'=>'Supr',
'LABEL_FROM'=>'De',
'LBL_INFO'=>'Info',
'LABEL_DATE'=>'Fecha',
'LBL_NO_IFRAMES_SUPPORTED'=>'Iframes no soportado',
'LBL_EMAIL_ATTACHMENTS'=>'Archivos adjuntos:',
'LBL_ALLMAILS'=>'Todos los Correos',
'LBL_TO_USERS'=>'A Usuarios',
'LBL_TO_GROUPS'=>'A Grupos',
'SUBJECT' => ' Asunto',
'BODY' => ' Cuerpo',
'TO' => ' Para:',
'CC' => ' CC:',
'BCC' => ' CCo:',
'FROM' => ' De:',
'IN'=>'en',
'ADD_FOLDER' => 'Agregar Carpeta [X]',
//Added for 5.0.3
'LBL_LOADING_IMAGE' => 'Cargando Imagen',
'LBL_ENABLE_IMAP_SUPPORT' => 'Active el soporte IMAP en php para activar el módulo',

// Added/Updated for vtiger CRM 5.0.4
'LBL_CONFIGURE_MAIL_SETTINGS'=>'Por Favor establezca la configuración de su Email',
'LBL_PLEASE'=>'Por Favor',
'LBL_HERE'=>'Aquí',

// Added after 5.0.4 GA
'LBL_FULL_EMAIL_VIEW'=>'Vista completa',
'LBL_MESSAGE'=>'Mensaje',
'LBL_MESSAGES'=>'Mensajes',

'LBL_NO_ATTACHMENTS'=>'No hay archivos adjuntos',
'LBL_THERE_ARE'=>'Hay ',
'LBL_ATTACHMENTS_TO_CHOOSE'=>' adjunto(s) para descargar',
'LBL_ATTACHMENTS'=>'Adjuntos',
'LBL_LIST_COUNT'=>'Mostrando',

);
?>

==> vtigercrm-5.4.0.tgz: modules/Webmails/language/es_mx.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Webmails
*  Language     : Español
*  Version      : 5.4.0
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2012-02-28
*  Author       : Odin Consultores, Francisco Hernandez
 ********************************************************************************/

$mod_strings = array (
'LBL_MODULE_NAME'=>'Webmail',
'LBL_MODULE_TITLE'=>'Webmail: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Email',
'LBL_LIST_FORM_TITLE'=>'Listado de Email',
'LBL_NEW_FORM_TITLE'=>'Seguimiento de Correo',

'LBL_LIST_SUBJECT'=>'Asunto',
'LBL_LIST_CONTACT'=>'Persona',
'LBL_LIST_RELATED_TO'=>'Relacionado con',
'LBL_LIST_DATE'=>'Fecha de Envío',
'LBL_LIST_TIME'=>'Hora de Envío',
'LBL_MOVE_TO'=>'Mover A',
'LBL_DELETE'=>'Borrar',

'ERR_DELETE_RECORD'=>'Debe especificar un registro para eliminar la cuenta.',
'LBL_DATE_SENT'=>'Fecha de Envío:',
'LBL_SUBJECT'=>'Asunto:',
'LBL_DATE_AND_TIME'=>'Fecha y Hora de Envío:',
'LBL_DATE'=>'Fecha de Envío:',
'LBL_TIME'=>'Hora de Envío:',
'LBL_BODY'=>'Cuerpo:',
'LBL_CONTACT_NAME'=>' Nombre: ',
'LBL_EMAIL'=>'Email:',
'LBL_COLON'=>':',
'LBL_TO'=>'Para :',
'LBL_CHK_MAIL'=>'Comprobar Correo',
'LBL_COMPOSE'=>'Redactar',
'LBL_SETTINGS'=>'Configuración',
'LBL_EMAIL_FOLDERS'=>'Carpetas de Email',
'LBL_INBOX'=>'Bandeja de Entrada',
'LBL_SENT_MAILS'=>'Emails Enviados',
'LBL_TRASH'=>'Papelera',
'LBL_JUNK_MAILS'=>'Eliminados',
'LBL_TO_LEADS'=>'A Prospectos',
'LBL_TO_CONTACTS'=>'A Contactos',
'LBL_TO_ACCOUNTS'=>'A Cuentas',
'LBL_MY_MAILS'=>'Mis Correos',
'LBL_QUAL_CONTACT'=>'Emails Clasificados por Contactos',
'LBL_MAILS'=>'Correos',
'LBL_QUALIFY_BUTTON'=>'Clasificar',
'LBL_REPLY_BUTTON'=>'Responder',
'LBL_FORWARD_BUTTON'=>'Reenviar',
'LBL_DOWNLOAD_ATTCH_BUTTON'=>'Descargar Adjuntos',
'LBL_FROM'=>'De: ',
'LBL_CC'=>'CC: ',
'LBL_REPLY_TO_SENDER'=>'Responder',
'LBL_REPLY_ALL'=>'Responder a Todos',
'LBL_SHOW_HIDDEN'=>'Mostrar Borrados',
'LBL_EXPUNGE_MAILBOX'=>'Borrar Mensajes',

'NTC_REMOVE_INVITEE'=>'¿Está seguro de eliminar esta dirección de Email?',
'LBL_INVITEE'=>'Receptores',

// Added Fields
// Contacts-SubPanelViewContactsAndUsers.php
'LBL_BULK_MAILS'=>'Email en blanco',
'LBL_ATTACHMENT'=>'Adjunto',
'LBL_UPLOAD'=>'Subir',
'LBL_FILE_NAME'=>'Nombre de Archivo',
'LBL_SEND'=>'Enviado',

'LBL_EMAIL_TEMPLATES'=>'Plantillas de Email',
'LBL_TEMPLATE_NAME'=>'Nombre de Plantilla',
'LBL_DESCRIPTION'=>'Descripción',
'LBL_EMAIL_TEMPLATES_LIST'=>'Lista de Plantillas de email',
'LBL_EMAIL_INFORMATION'=>'Información de Email',




//for v4 release added
'LBL_NEW_LEAD'=>'Nuevo Prospecto',
'LBL_LEAD_TITLE'=>'Prospecto',

'LBL_NEW_PRODUCT'=>'Nuevo Producto',
'LBL_PRODUCT_TITLE'=>'Productos',
'LBL_NEW_CONTACT'=>'Nuevo Contacto',
'LBL_CONTACT_TITLE'=>'Contactos',
'LBL_NEW_ACCOUNT'=>'Nueva Cuenta',
'LBL_ACCOUNT_TITLE'=>'Cuentas',

// Added vtiger_fields after vtiger4 - Beta
'LBL_USER_TITLE'=>'Usuarios',
'LBL_NEW_USER'=>'Nuevo Usuario',

// Added for 4 GA
'LBL_TOOL_FORM_TITLE'=>'Herramienta de Email',
//Added for 4GA
'Date & Time Sent'=>'Fecha y Hora de Envío',
'Sales Enity Module'=>'Módulo de Ventas',
'Activtiy Type'=>'Tipo de Actividad',
'Related To'=>'Relacionado con',
'Assigned To'=>'Asignado a',
'Subject'=>'Asunto',
'Attachment'=>'Adjunto',
'Description'=>'Descripción',
'Time Start'=>'Fecha de Inicio',
'Created Time'=>'Creada',
'Modified Time'=>'Modificada',

'MESSAGE_CHECK_MAIL_SERVER_NAME'=>'Por favor compruebe el nombre del servidor de mail...',
'MESSAGE_CHECK_MAIL_ID'=>'Por favor compruebe el Email del usuario "Asignado a"...',
'MESSAGE_MAIL_HAS_SENT_TO_USERS'=>'El correo se ha enviado a los siguientes usuarios:',
'MESSAGE_MAIL_HAS_SENT_TO_CONTACTS'=>'El correo se ha enviado a los siguientes contactos:',
'MESSAGE_MAIL_ID_IS_INCORRECT'=>'El Email es incorrecto. Compruebe el Email ...',
'MESSAGE_ADD_USER_OR_CONTACT'=>'Añada un Usuario o Contacto...',
'MESSAGE_MAIL_SENT_SUCCESSFULLY'=>' ¡El Email se ha enviado correctamente!',

// Added for web mail post 4.0.1 release
'LBL_FETCH_WEBMAIL'=>'Actualizar Correo',
//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'Todos',
'MESSAGE_CONTACT_NOT_WANT_MAIL'=>'Este contacto no quiere recibir correos.',
'LBL_WEBMAILS_TITLE'=>'Email',
'LBL_EMAILS_TITLE'=>'Email',
'LBL_MAIL_CONNECT_ERROR_INFO'=>'¡Error conectando con el servidor de email!<br> Compruebe en Configuración -> Lista de Servidores de Correo -> Lista de cuentas de correo',
// Added for 5.0.3 release
'LBL_MAIL_CONNECT_ERROR'=>'No se ha podido conectar al Servidor de Correo. Compruebe la configuración del Servidor ',
'IN_REPLY_TO_THE_MESSAGE' => 'En respuesta al mensaje enviado por',
'LBL_CLICK_HERE' => 'Pinche Aquí ',
'LBL_GOTO_EMAILS_MODULE' => ' para ir al módulo de Email',
'LBL_NO_EMAILS'=>'Carpeta vacía',
'LBL_MOVE_TO'=>'Mover a...',
'LBL_DEL'=>'Supr',
'LABEL_FROM'=>'De',
'LBL_INFO'=>'Info',
'LABEL_DATE'=>'Fecha',
'LBL_NO_IFRAMES_SUPPORTED'=>'Iframes no soportado',
'LBL_EMAIL_ATTACHMENTS'=>'Archivos adjuntos:',
'LBL_ALLMAILS'=>'Todos los Correos',
'LBL_TO_USERS'=>'A Usuarios',
'LBL_TO_GROUPS'=>'A Grupos',
'SUBJECT' => ' Asunto',
'BODY' => ' Cuerpo',
'TO' => ' Para:',
'CC' => ' CC:',
'BCC' => ' CCo:',
'FROM' => ' De:',
'IN'=>'en',
'ADD_FOLDER' => 'Agregar Carpeta [X]',
//Added for 5.0.3
'LBL_LOADING_IMAGE' => 'Cargando Imagen',
'LBL_ENABLE_IMAP_SUPPORT' => 'Active el soporte IMAP en php para activar el módulo',

// Added/Updated for vtiger CRM 5.0.4
'LBL_CONFIGURE_MAIL_SETTINGS'=>'Por Favor establezca la configuración de su Email',
'LBL_PLEASE'=>'Por Favor',
'LBL_HERE'=>'Aquí',

// Added after 5.0.4 GA
'LBL_FULL_EMAIL_VIEW'=>'Vista completa',
'LBL_MESSAGE'=>'Mensaje',
'LBL_MESSAGES'=>'Mensajes',

'LBL_NO_ATTACHMENTS'=>'No hay archivos adjuntos',
'LBL_THERE_ARE'=>'Hay ',
'LBL_ATTACHMENTS_TO_CHOOSE'=>' adjunto(s) para descargar',
'LBL_ATTACHMENTS'=>'Adjuntos',
'LBL_LIST_COUNT'=>'Mostrando',

'LBL_INSTEAD_OF_WEBMAILS_USE' => 'En vez de Webmail, utiliza',
'LBL_PLEASE_CLICK_HERE_TO_GO_TO' => 'Haz click aquí para ir a ',
);
?>
